@@ -6,13 +6,15 @@ BEGIN {
   $Dist::Zilla::Plugin::MetaData::BuiltWith::AUTHORITY = 'cpan:KENTNL';
 }
 {
-  $Dist::Zilla::Plugin::MetaData::BuiltWith::VERSION = '0.03000000';
+  $Dist::Zilla::Plugin::MetaData::BuiltWith::VERSION = '0.03000100';
 }
 
 # ABSTRACT: Report what versions of things your distribution was built against
 
 
-use Dist::Zilla::Util::EmulatePhase 0.01000101 qw( get_prereqs );
+use Dist::Zilla::Util::EmulatePhase;
+use Readonly;
+Readonly my $MIN_EMULATE_PHASE => '0.01000101';
 use Moose 2.0;
 use Class::Load qw( load_optional_class );
 use MooseX::Types::Moose (qw( ArrayRef Bool Str ));
@@ -22,7 +24,6 @@ with 'Dist::Zilla::Role::MetaProvider';
 
 sub mvp_multivalue_args { return qw( exclude include ) }
 
-
 has _exclude => (
   init_arg => 'exclude',
   is       => 'ro',
@@ -32,7 +33,6 @@ has _exclude => (
   handles  => { exclude => 'elements', },
 );
 
-
 has _include => (
   init_arg => 'include',
   is       => 'ro',
@@ -45,15 +45,9 @@ has _include => (
 
 
 has show_config => ( is => 'ro', isa => 'Bool', default => 0 );
-
-
 has show_uname => ( is => 'ro', isa => Bool, default => 0 );
-
-
-has uname_call => ( is => 'ro', isa => Str, default => 'uname' );
-
-
-has uname_args => ( is => 'ro', isa => Str, default => '-a' );
+has uname_call => ( is => 'ro', isa => Str,  default => 'uname' );
+has uname_args => ( is => 'ro', isa => Str,  default => '-a' );
 has _uname_args => (
   init_arg   => undef,
   is         => 'ro',
@@ -68,7 +62,7 @@ around dump_config => sub {
   my ( $orig, $self ) = @_;
 
   my $config = $self->$orig();
-  my $thisconfig = { show_uname => $self->show_uname, _stash_key => $self->_stash_key, show_config => $self->show_config };
+  my $thisconfig = { show_uname => $self->show_uname, _stash_key => $self->_stash_key , show_config => $self->show_config };
 
   if ( $self->show_uname ) {
     $thisconfig->{'uname'} = {
@@ -142,7 +136,10 @@ sub _get_prereq_modnames {
 
   my $modnames = {};
 
-  my $prereqs = get_prereqs( { zilla => $self->zilla } )->as_string_hash;
+  if ( defined $Dist::Zilla::Util::EmulatePhase::VERSION ) {
+    Dist::Zilla::Util::EmulatePhase->VERSION($MIN_EMULATE_PHASE);
+  }
+  my $prereqs = Dist::Zilla::Util::EmulatePhase::get_prereqs( { zilla => $self->zilla } )->as_string_hash;
   if ( not %{$prereqs} ) {
     $self->log(q{WARNING: No prereqs were found, probably a bug});
     return [];
@@ -262,7 +259,7 @@ Dist::Zilla::Plugin::MetaData::BuiltWith - Report what versions of things your d
 
 =head1 VERSION
 
-version 0.03000000
+version 0.03000100
 
 =head1 SYNOPSIS
 
